User Guide
==========

Documentation is split into four categories, also accessible from links in the side-bar.

.. grid:: 2
    :gutter: 4

    .. grid-item-card:: :material-regular:`directions_walk;3em`

        .. toctree::
            :caption: Tutorials
            :maxdepth: 1

            tutorials/02-starting_backend
            tutorials/03-starting_frontend

        +++

        Tutorials for installation and typical usage. New users start here.

    .. grid-item-card:: :material-regular:`directions;3em`

        .. toctree::
            :caption: How-to Guides
            :maxdepth: 1

            how-to/01-installing_development
            how-to/03-starting_development

        +++

        Practical step-by-step guides for the more experienced user.

    .. grid-item-card:: :material-regular:`info;3em`

        .. toctree::
            :caption: Explanations
            :maxdepth: 1

            explanations/22-developing
            explanations/23-testing
            explanations/24-devops
            explanations/25-docs-structure

        +++

        Explanations of how the library works and why it works that way.

    .. grid-item-card:: :material-regular:`menu_book;3em`

        .. toctree::
            :caption: Reference
            :maxdepth: 1

            reference/01-conda
            reference/api

        +++

        Technical reference material including APIs and release notes.
